// ตัวแปรสำหรับเก็บ token
let authToken = localStorage.getItem('token');

// Elements
const loginBtn = document.getElementById('loginBtn');
const registerBtn = document.getElementById('registerBtn');
const loginModal = document.getElementById('loginModal');
const registerModal = document.getElementById('registerModal');
const loginForm = document.getElementById('loginForm');
const registerForm = document.getElementById('registerForm');
const productsList = document.getElementById('productsList');
const categoriesList = document.getElementById('categoriesList');
const editModal = document.getElementById('editModal');
const editForm = document.getElementById('editForm');
const addModal = document.getElementById('addModal');
const addForm = document.getElementById('addForm');

// Event Listeners
loginBtn.addEventListener('click', () => loginModal.style.display = 'block');
registerBtn.addEventListener('click', () => registerModal.style.display = 'block');

// ปิด Modal เมื่อคลิกนอกกรอบ
window.onclick = (event) => {
    if (event.target === loginModal) loginModal.style.display = 'none';
    if (event.target === registerModal) registerModal.style.display = 'none';
    if (event.target === editModal) editModal.style.display = 'none';
    if (event.target === addModal) addModal.style.display = 'none';
};

// Login Form Submit
loginForm.addEventListener('submit', async (e) => {
    e.preventDefault();
    const username = document.getElementById('loginUsername').value;
    const password = document.getElementById('loginPassword').value;

    try {
        const response = await fetch('http://localhost:3000/login', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({ username, password })
        });

        const data = await response.json();
        if (response.ok) {
            authToken = data.token;
            localStorage.setItem('token', authToken);
            loginModal.style.display = 'none';
            alert('เข้าสู่ระบบสำเร็จ');
            updateUI();
        } else {
            alert(data.error || 'เข้าสู่ระบบไม่สำเร็จ');
        }
    } catch (error) {
        alert('เกิดข้อผิดพลาดในการเชื่อมต่อ');
    }
});

// Register Form Submit
registerForm.addEventListener('submit', async (e) => {
    e.preventDefault();
    const username = document.getElementById('regUsername').value;
    const email = document.getElementById('regEmail').value;
    const password = document.getElementById('regPassword').value;

    try {
        const response = await fetch('http://localhost:3000/register', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({ username, email, password })
        });

        const data = await response.json();
        if (response.ok) {
            registerModal.style.display = 'none';
            alert('สมัครสมาชิกสำเร็จ กรุณาเข้าสู่ระบบ');
        } else {
            alert(data.error || 'สมัครสมาชิกไม่สำเร็จ');
        }
    } catch (error) {
        alert('เกิดข้อผิดพลาดในการเชื่อมต่อ');
    }
});

// ฟังก์ชันสำหรับค้นหาสินค้า
async function searchProducts() {
    const searchInput = document.getElementById('searchInput').value;
    try {
        const response = await fetch(`http://localhost:3000/api/products/search?name=${searchInput}`);
        const products = await response.json();
        displayProducts(products);
    } catch (error) {
        console.error('Error searching products:', error);
    }
}

// ฟังก์ชันแสดงสินค้า
function displayProducts(products) {
    productsList.innerHTML = products.map(product => `
        <div class="product-card">
            <div class="product-image">
                ${product.image_url ? 
                    `<img src="uploads/${product.image_url}" alt="${product.name}">` : 
                    '<div class="no-image">ไม่มีรูปภาพ</div>'
                }
            </div>
            <div class="product-info">
                <h3>${product.name}</h3>
                <p>หมวดหมู่: ${product.category_name || 'ไม่ระบุ'}</p>
                <p>ผู้จัดจำหน่าย: ${product.supplier_name || 'ไม่ระบุ'}</p>
                <p>ติดต่อ: ${product.contact_name || 'ไม่ระบุ'} (${product.supplier_phone || 'ไม่ระบุ'})</p>
                <p>สินค้าคงเหลือ: ${product.stock || 0} ชิ้น</p>
                <p class="product-price">฿${product.price}</p>
                <div class="product-actions">
                    <button onclick="editProduct(${product.id}, ${JSON.stringify(product).replace(/"/g, '&quot;')})">แก้ไข</button>
                    <button onclick="deleteProduct(${product.id})">ลบ</button>
                </div>
            </div>
        </div>
    `).join('');
}

// ฟังก์ชันแสดงหมวดหมู่
function displayCategories(categories) {
    categoriesList.innerHTML = categories.map(category => `
        <div class="category-item" onclick="filterByCategory(${category.id})">
            ${category.name}
        </div>
    `).join('');
}

// ฟังก์ชันกรองสินค้าตามหมวดหมู่
async function filterByCategory(categoryId) {
    try {
        const response = await fetch(`http://localhost:3000/api/products?categoryId=${categoryId}`);
        const products = await response.json();
        displayProducts(products);
    } catch (error) {
        console.error('Error filtering products:', error);
    }
}

// ฟังก์ชันอัพเดท UI
function updateUI() {
    if (authToken) {
        loginBtn.style.display = 'none';
        registerBtn.style.display = 'none';
        // เพิ่มปุ่มออกจากระบบ
        const logoutBtn = document.createElement('button');
        logoutBtn.textContent = 'ออกจากระบบ';
        logoutBtn.onclick = logout;
        document.querySelector('.nav-buttons').appendChild(logoutBtn);
    }
}

// ฟังก์ชันออกจากระบบ
function logout() {
    localStorage.removeItem('token');
    authToken = null;
    location.reload();
}

// โหลดข้อมูลเริ่มต้น
async function loadInitialData() {
    try {
        // โหลดสินค้า
        const productsResponse = await fetch('http://localhost:3000/api/products');
        const products = await productsResponse.json();
        displayProducts(products);

        // โหลดหมวดหมู่
        const categoriesResponse = await fetch('http://localhost:3000/api/categories');
        const categories = await categoriesResponse.json();
        displayCategories(categories);
    } catch (error) {
        console.error('Error loading initial data:', error);
    }
}

// เรียกใช้ฟังก์ชันเมื่อโหลดหน้าเว็บ
loadInitialData();
updateUI();

// ฟังก์ชันแก้ไขสินค้า (เปิด Modal)
async function editProduct(id, product) {
    document.getElementById('editProductId').value = id;
    document.getElementById('editName').value = product.name;
    document.getElementById('editPrice').value = product.price;
    document.getElementById('editStock').value = product.stock;
    
    // แสดงรูปภาพปัจจุบัน (ถ้ามี)
    const currentImageDiv = document.getElementById('currentImage');
    if (product.image_url) {
        currentImageDiv.innerHTML = `
            <p>รูปภาพปัจจุบัน:</p>
            <img src="uploads/${product.image_url}" alt="${product.name}" style="max-width: 200px;">
        `;
    } else {
        currentImageDiv.innerHTML = '<p>ไม่มีรูปภาพ</p>';
    }
    
    try {
        const [categoriesResponse, suppliersResponse] = await Promise.all([
            fetch('http://localhost:3000/api/categories'),
            fetch('http://localhost:3000/api/suppliers')
        ]);
        
        const categories = await categoriesResponse.json();
        const suppliers = await suppliersResponse.json();
        
        const categorySelect = document.getElementById('editCategory');
        categorySelect.innerHTML = categories.map(category => 
            `<option value="${category.id}" ${category.id === product.category_id ? 'selected' : ''}>
                ${category.name}
            </option>`
        ).join('');
        
        const supplierSelect = document.getElementById('editSupplier');
        supplierSelect.innerHTML = suppliers.map(supplier => 
            `<option value="${supplier.id}" ${supplier.id === product.supplier_id ? 'selected' : ''}>
                ${supplier.name}
            </option>`
        ).join('');
        
        editModal.style.display = 'block';
    } catch (error) {
        alert('เกิดข้อผิดพลาดในการโหลดข้อมูล');
    }
}

// ฟังก์ชันปิด Edit Modal
function closeEditModal() {
    editModal.style.display = 'none';
}

// เพิ่ม Event Listener สำหรับการ submit form แก้ไขสินค้า
editForm.addEventListener('submit', async (e) => {
    e.preventDefault();
    
    const id = document.getElementById('editProductId').value;
    const name = document.getElementById('editName').value;
    const price = document.getElementById('editPrice').value;
    const stock = document.getElementById('editStock').value;
    const category_id = document.getElementById('editCategory').value;
    const supplier_id = document.getElementById('editSupplier').value;
    const imageFile = document.getElementById('editImage').files[0];

    // ตรวจสอบขนาดไฟล์
    if (imageFile && imageFile.size > 5 * 1024 * 1024) {
        alert('ขนาดไฟล์ใหญ่เกินไป กรุณาอัพโหลดไฟล์ขนาดไม่เกิน 5MB');
        return;
    }
    
    const formData = new FormData();
    formData.append('name', name);
    formData.append('price', price);
    formData.append('stock', stock);
    formData.append('category_id', category_id);
    formData.append('supplier_id', supplier_id);
    if (imageFile) {
        formData.append('image', imageFile);
    }
    
    try {
        const response = await fetch(`http://localhost:3000/api/products/${id}`, {
            method: 'PUT',
            body: formData
        });
        
        const data = await response.json();
        if (response.ok) {
            alert('แก้ไขสินค้าสำเร็จ');
            closeEditModal();
            loadInitialData();
        } else {
            alert(data.error || 'แก้ไขสินค้าไม่สำเร็จ');
        }
    } catch (error) {
        console.error('Error:', error);
        alert('เกิดข้อผิดพลาดในการเชื่อมต่อ');
    }
});

// ฟังก์ชันลบสินค้า
async function deleteProduct(id) {
    if (!confirm('คุณแน่ใจหรือไม่ที่จะลบสินค้านี้?')) {
        return;
    }
    
    try {
        const response = await fetch(`http://localhost:3000/api/products/${id}`, {
            method: 'DELETE'
        });
        
        const data = await response.json();
        if (response.ok) {
            alert('ลบสินค้าสำเร็จ');
            loadInitialData(); // โหลดข้อมูลใหม่
        } else {
            alert(data.error || 'ลบสินค้าไม่สำเร็จ');
        }
    } catch (error) {
        alert('เกิดข้อผิดพลาดในการเชื่อมต่อ');
    }
}

// ฟังก์ชันเปิด Add Modal
function openAddModal() {
    // โหลดข้อมูลหมวดหมู่และผู้จัดจำหน่าย
    Promise.all([
        fetch('http://localhost:3000/api/categories'),
        fetch('http://localhost:3000/api/suppliers')
    ]).then(async ([categoriesResponse, suppliersResponse]) => {
        const categories = await categoriesResponse.json();
        const suppliers = await suppliersResponse.json();
        
        // สร้าง options สำหรับ select หมวดหมู่
        const categorySelect = document.getElementById('addCategory');
        categorySelect.innerHTML = categories.map(category => 
            `<option value="${category.id}">${category.name}</option>`
        ).join('');
        
        // สร้าง options สำหรับ select ผู้จัดจำหน่าย
        const supplierSelect = document.getElementById('addSupplier');
        supplierSelect.innerHTML = suppliers.map(supplier => 
            `<option value="${supplier.id}">${supplier.name}</option>`
        ).join('');
        
        addModal.style.display = 'block';
    }).catch(error => {
        alert('เกิดข้อผิดพลาดในการโหลดข้อมูล');
    });
}

// ฟังก์ชันปิด Add Modal
function closeAddModal() {
    addModal.style.display = 'none';
    addForm.reset();
}

// เพิ่ม Event Listener สำหรับการ submit form เพิ่มสินค้า
addForm.addEventListener('submit', async (e) => {
    e.preventDefault();
    
    const name = document.getElementById('addName').value;
    const price = document.getElementById('addPrice').value;
    const stock = document.getElementById('addStock').value;
    const category_id = document.getElementById('addCategory').value;
    const supplier_id = document.getElementById('addSupplier').value;
    const imageFile = document.getElementById('addImage').files[0];
    
    // ตรวจสอบขนาดไฟล์
    if (imageFile && imageFile.size > 5 * 1024 * 1024) {
        alert('ขนาดไฟล์ใหญ่เกินไป กรุณาอัพโหลดไฟล์ขนาดไม่เกิน 5MB');
        return;
    }
    
    const formData = new FormData();
    formData.append('name', name);
    formData.append('price', price);
    formData.append('stock', stock);
    formData.append('category_id', category_id);
    formData.append('supplier_id', supplier_id);
    if (imageFile) {
        formData.append('image', imageFile);
    }
    
    try {
        const response = await fetch('http://localhost:3000/api/products', {
            method: 'POST',
            body: formData
        });
        
        const data = await response.json();
        if (response.ok) {
            alert('เพิ่มสินค้าสำเร็จ');
            closeAddModal();
            loadInitialData();
        } else {
            alert(data.error || 'เพิ่มสินค้าไม่สำเร็จ');
        }
    } catch (error) {
        console.error('Error:', error);
        alert('เกิดข้อผิดพลาดในการเชื่อมต่อ');
    }
}); 